const path = require('path');
const fse = require('fs-extra');
const insertReportToDatabase = require('./insertReportToDatabase');

function extractReporterOptions(options) {
  if (!options) {
    return undefined;
  }
  
  // Only this reporter enabled
  if (!options.reporterEnabled) {
    return options;
  }
}

async function getCypressConfig(configPath) {
  let config = {};
  
  try {
    config = await fse.readJson(configPath);
  } catch {
    console.warn(`Couldn't find cypress.json file in "${configPath}", continue with default config`);
  }
  
  const baseDir = path.dirname(configPath);
  
  return {
    dbReporterOptions: extractReporterOptions(config.dbReporterOptions),
  };
}
async function normalizeOptions({
                                  cypressConfig: cypressConfigPath,
                                  jsonDir,
                                  ...dbReporterOptions
                                }) {
  console.log(`Read cypress config file from "${cypressConfigPath}"`);
  const cypressConfig = await getCypressConfig(cypressConfigPath);
  
  return {
    dbReporterOptions: { ...cypressConfig.dbReporterOptions, ...dbReporterOptions },
  };
}

async function insertReport(options) {

  const { dbReporterOptions } = await normalizeOptions(options);
  
  insertReportToDatabase(dbReporterOptions)
  
  //console.log('HTML report successfully created!');
}


module.exports = { insertReport };